@@ -6,7 +6,6 @@ from .models import Service, AuthenticationRequest
 class ServiceAdmin(admin.ModelAdmin):
 	list_display = 'name', 'base_url', 'enabled'
 	fields = 'name', 'base_url', 'token', 'enabled'
-	readonly_fields = 'token',
 
 
 @admin.register(AuthenticationRequest)
@@ -24,8 +23,8 @@ class AuthenticationRequestAdmin(admin.ModelAdmin):
 	def has_change_permission(self, *args, **kwargs):
 		return False
 
-	def has_delete_permission(self, *args, **kwargs):
-		return False
+	def has_delete_permission(self, request, *args, **kwargs):
+		return request.user.is_superuser
 
 	list_filter = 'service__name', 'used'
 	search_fields = 'user_identy',
